Riverbed SteelScript Application Framework - Stock Report
=========================================================

The SteelScript Application Framework makes it easy to create a fully
custom web application that mashes up data from multiple sources.  This
package demonstrates the use of an external datasource and custom reports for
the App Framework.

For a complete guide to installation, see:

  `https://support.riverbed.com/apis/steelscript/index.html <https://support.riverbed.com/apis/steelscript/index.html>`_

License
=======

Copyright (c) 2015 Riverbed Technology, Inc.

SteelScript-Stock is licensed under the terms and conditions of
the MIT License accompanying the software ("License").
SteelScript-Stock is distributed "AS IS" as set forth in the
License.

